@@ -61,6 +61,7 @@
 #include "../../wrapper/ringbuffer/iterator.h"
 #include "../../wrapper/ringbuffer/nohz.h"
 #include "../../wrapper/atomic.h"
+#include "../../wrapper/kref.h"
 #include "../../wrapper/percpu-defs.h"
 
 /*
@@ -793,7 +794,10 @@ int lib_ring_buffer_open_read(struct lib_ring_buffer *buf)
 
 	if (!atomic_long_add_unless(&buf->active_readers, 1, 1))
 		return -EBUSY;
-	kref_get(&chan->ref);
+	if (!lttng_kref_get(&chan->ref)) {
+		atomic_long_dec(&buf->active_readers);
+		return -EOVERFLOW;
+	}
 	lttng_smp_mb__after_atomic();
 	return 0;
 }
